@@ -14,13 +14,13 @@
 #    under the License.
 
 import mock
-from oslotest import base as test_base
 
 from ironic_python_agent.extensions import log
+from ironic_python_agent.tests.unit import base
 from ironic_python_agent import utils
 
 
-class TestLogExtension(test_base.BaseTestCase):
+class TestLogExtension(base.IronicAgentTest):
 
     def setUp(self):
         super(TestLogExtension, self).setUp()
