@@ -118,29 +118,12 @@ class TestIntelCnaHardwareManager(base.IronicAgentTest):
 
     @mock.patch.object(cna, 'LOG', autospec=True)
     @mock.patch.object(cna, '_detect_cna_card', autospec=True)
-    def test_evaluate_hardware_support_with_collect_lldp_disabled(
-            self, mock_detect_card, mock_log):
+    def test_evaluate_hardware_support(self, mock_detect_card, mock_log):
         mock_detect_card.return_value = True
         expected_support = hardware.HardwareSupport.MAINLINE
         actual_support = self.hardware.evaluate_hardware_support()
         self.assertEqual(expected_support, actual_support)
-        mock_log.debug.assert_called_once_with('Found Intel CNA network card')
-
-    @mock.patch.object(cna, 'LOG', autospec=True)
-    @mock.patch.object(cna, '_detect_cna_card', autospec=True)
-    @mock.patch.object(cna, '_disable_embedded_lldp_agent_in_cna_card',
-                       autospec=True)
-    def test_evaluate_hardware_support_with_collect_lldp_enabled(
-            self, mock_disable_lldp_agent, mock_detect_card, mock_log):
-        self.config(collect_lldp=True)
-        mock_detect_card.return_value = True
-        expected_support = hardware.HardwareSupport.MAINLINE
-        actual_support = self.hardware.evaluate_hardware_support()
-        self.assertEqual(expected_support, actual_support)
-        mock_log.debug.assert_called_once_with('Found Intel CNA network card')
-        mock_log.info.assert_called_once_with(
-            'Disable CNA network card embedded lldp agent now')
-        mock_disable_lldp_agent.assert_called_once_with()
+        mock_log.debug.assert_called_once()
 
     @mock.patch.object(cna, 'LOG', autospec=True)
     @mock.patch.object(cna, '_detect_cna_card', autospec=True)
@@ -151,5 +134,20 @@ class TestIntelCnaHardwareManager(base.IronicAgentTest):
         expected_support = hardware.HardwareSupport.NONE
         actual_support = self.hardware.evaluate_hardware_support()
         self.assertEqual(expected_support, actual_support)
-        mock_log.debug.assert_called_once_with(
-            'No Intel CNA network card found')
+        mock_log.debug.assert_called_once()
+
+    @mock.patch.object(hardware.GenericHardwareManager, 'collect_lldp_data',
+                       autospec=True)
+    def test_collect_lldp_data(self, mock_super_collect):
+        iface_names = ['eth0', 'eth1']
+        returned_lldp_data = [
+            (0, 'foo'),
+            (1, 'bar'),
+        ]
+        mock_super_collect.return_value = returned_lldp_data
+        with mock.patch.object(cna, '_disable_embedded_lldp_agent_in_cna_card',
+                               autospec=True):
+            result = self.hardware.collect_lldp_data(iface_names)
+            mock_super_collect.assert_called_once_with(self.hardware,
+                                                       iface_names)
+            self.assertEqual(returned_lldp_data, result)
