@@ -22,6 +22,7 @@ import subprocess
 import tarfile
 import tempfile
 
+from ironic_lib import disk_utils
 from ironic_lib import utils as ironic_utils
 import mock
 from oslo_concurrency import processutils
@@ -46,30 +47,6 @@ Number  Start   End     Size    File system  Name  Flags
  1      116MB   2361MB  2245MB  ext4
 '''
 
-PARTED_OUTPUT_UNFORMATTED_NOFS = '''Model: whatever
-Disk /dev/sda: 480GB
-Sector size (logical/physical): 512B/512B
-Partition Table: gpt
-Disk Flags:
-
-Number  Start   End     Size    File system  Name  Flags
-1      1049kB  9437kB  8389kB                ESP   boot, esp
-2      9437kB  17.8MB  8389kB                BSP   bios_grub
-3      17.8MB  40.0GB  40.0GB
-4      479GB   480GB   68.1MB
-'''
-
-PARTED_OUTPUT_NO_EFI = '''Model: whatever
-Disk /dev/sda: 450GB
-Sector size (logical/physical): 512B/512B
-Partition Table: gpt
-Disk Flags:
-
-Number  Start   End     Size    File system  Name  Flags
-14      1049kB  5243kB  4194kB                     bios_grub
- 1      116MB   2361MB  2245MB  ext4
-'''
-
 
 class ExecuteTestCase(ironic_agent_base.IronicAgentTest):
     # This test case does call utils.execute(), so don't block access to the
@@ -630,35 +607,73 @@ class TestUtils(testtools.TestCase):
         )
 
     @mock.patch.object(utils, 'execute', autospec=True)
-    def test_get_efi_part_on_device(self, mocked_execute):
-        parted_ret = PARTED_OUTPUT_UNFORMATTED.format('gpt')
+    def test_scan_partition_table_type_gpt(self, mocked_execute):
+        self._test_scan_partition_table_by_type(mocked_execute, 'gpt', 'gpt')
+
+    @mock.patch.object(utils, 'execute', autospec=True)
+    def test_scan_partition_table_type_msdos(self, mocked_execute):
+        self._test_scan_partition_table_by_type(mocked_execute, 'msdos',
+                                                'msdos')
+
+    @mock.patch.object(utils, 'execute', autospec=True)
+    def test_scan_partition_table_type_unknown(self, mocked_execute):
+        self._test_scan_partition_table_by_type(mocked_execute, 'whatever',
+                                                'unknown')
+
+    def _test_scan_partition_table_by_type(self, mocked_execute,
+                                           table_type_output,
+                                           expected_table_type):
+
+        parted_ret = PARTED_OUTPUT_UNFORMATTED.format(table_type_output)
+
         mocked_execute.side_effect = [
-            (parted_ret, None)
+            (parted_ret, None),
+        ]
+
+        ret = utils.scan_partition_table_type('hello')
+        mocked_execute.assert_has_calls(
+            [mock.call('parted', '-s', 'hello', '--', 'print')]
+        )
+        self.assertEqual(expected_table_type, ret)
+
+
+@mock.patch.object(disk_utils, 'list_partitions', autospec=True)
+@mock.patch.object(utils, 'scan_partition_table_type', autospec=True)
+class TestGetEfiPart(testtools.TestCase):
+
+    def test_get_efi_part_on_device(self, mocked_type, mocked_parts):
+        mocked_parts.return_value = [
+            {'number': '1', 'flags': ''},
+            {'number': '14', 'flags': 'bios_grub'},
+            {'number': '15', 'flags': 'esp, boot'},
         ]
         ret = utils.get_efi_part_on_device('/dev/sda')
-        mocked_execute.assert_has_calls(
-            [mock.call('parted', '-s', '/dev/sda', '--', 'print')]
-        )
         self.assertEqual('15', ret)
 
-    @mock.patch.object(utils, 'execute', autospec=True)
-    def test_get_efi_part_on_device_without_fs(self, mocked_execute):
-        parted_ret = PARTED_OUTPUT_UNFORMATTED_NOFS.format('gpt')
-        mocked_execute.side_effect = [
-            (parted_ret, None)
+    def test_get_efi_part_on_device_only_boot_flag_gpt(self, mocked_type,
+                                                       mocked_parts):
+        mocked_type.return_value = 'gpt'
+        mocked_parts.return_value = [
+            {'number': '1', 'flags': ''},
+            {'number': '14', 'flags': 'bios_grub'},
+            {'number': '15', 'flags': 'boot'},
         ]
         ret = utils.get_efi_part_on_device('/dev/sda')
-        mocked_execute.assert_has_calls(
-            [mock.call('parted', '-s', '/dev/sda', '--', 'print')]
-        )
-        self.assertEqual('1', ret)
+        self.assertEqual('15', ret)
 
-    @mock.patch.object(utils, 'execute', autospec=True)
-    def test_get_efi_part_on_device_not_found(self, mocked_execute):
-        mocked_execute.side_effect = [
-            (PARTED_OUTPUT_NO_EFI, None)
+    def test_get_efi_part_on_device_only_boot_flag_mbr(self, mocked_type,
+                                                       mocked_parts):
+        mocked_type.return_value = 'msdos'
+        mocked_parts.return_value = [
+            {'number': '1', 'flags': ''},
+            {'number': '14', 'flags': 'bios_grub'},
+            {'number': '15', 'flags': 'boot'},
+        ]
+        self.assertIsNone(utils.get_efi_part_on_device('/dev/sda'))
+
+    def test_get_efi_part_on_device_not_found(self, mocked_type, mocked_parts):
+        mocked_parts.return_value = [
+            {'number': '1', 'flags': ''},
+            {'number': '14', 'flags': 'bios_grub'},
         ]
         self.assertIsNone(utils.get_efi_part_on_device('/dev/sda'))
-        mocked_execute.assert_has_calls(
-            [mock.call('parted', '-s', '/dev/sda', '--', 'print')]
-        )
